@@ -12,18 +12,26 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
+from django.template import Context
 from django.http import HttpResponse
 
 import middleware
 
-def render_to_string(template_name, data_dictionary):
+def render_to_string(template_name, dictionary, context_instance=None):
+    context_instance = context_instance or Context(dictionary)
+    # add dictionary to context_instance
+    context_instance.update(dictionary or {})
+    # collapse context_instance to a single dictionary for mako
+    context_dictionary = {}
+    for d in context_instance:
+        context_dictionary.update(d)
+    # fetch and render template
     template = middleware.lookup.get_template(template_name)
-    result = template.render(**data_dictionary)
-    return result
+    return template.render(**dictionary)
 
-def render_to_response(template_name, data_dictionary, **kwargs):
+def render_to_response(template_name, dictionary, context_instance=None, **kwargs):
     """
     Returns a HttpResponse whose content is filled with the result of calling
     lookup.get_template(args[0]).render with the passed arguments.
     """
-    return HttpResponse(render_to_string(template_name, data_dictionary), **kwargs)
+    return HttpResponse(render_to_string(template_name, dictionary, context_instance), **kwargs)
